@@ -36,3 +36,6 @@ fi
 if ! grep -iq "Project-Id-Version:.* ${version}\\\\n" src/po/de.po; then
 	echo "*** WARNING: version in de.po out of date         ***"
 fi
+if grep -iq "fuzzy" src/po/??.po; then
+	echo "*** WARNING: fuzzy strings in some .po file       ***"
+fi
