@@ -295,7 +295,8 @@ void do_opts(int argc, char *argv[], int *force)
 			}
 			break;
 		case 'h':
-			printf(_("Usage: %s [options] [dictionary|path]\n"
+			printf(/* TRANSLATORS: Please wrap lines, which are longer than 80 characters. */
+				_("Usage: %s [options] [dictionary|path]\n"
 				"  -d, --debug                turn on debug mode,\n"
 				"      --direction={0|1|2|3}  initial direction for input fields,\n"
 				"  -f, --force                overwrite stale lock files,\n"
@@ -319,7 +320,8 @@ void do_opts(int argc, char *argv[], int *force)
 					"");
 #endif
 			printf("Copyright (c) 2002-2004 Martin A. Godisch <martin@godisch.de>\n");
-			printf(_("English localization by Martin A. Godisch <martin@godisch.de>\n"));
+			printf(/* TRANSLATORS: Please add your own credits for your translation here. */
+				_("English localization by Martin A. Godisch <martin@godisch.de>\n"));
 			exit(0);
 		case '?':
 			exit(1);
